import { Injectable, NgZone, Component, ViewEncapsulation, ChangeDetectionStrategy, Inject, PLATFORM_ID, ElementRef, Input, Output, InjectionToken, Directive, Self, Optional, LOCALE_ID, NgModule } from '@angular/core';
import { isPlatformBrowser, CommonModule } from '@angular/common';
import { BehaviorSubject, ReplaySubject, from, timer, Observable, Subject } from 'rxjs';
import { mergeMap, sample, switchMap, map, shareReplay, take, filter, takeUntil, distinctUntilChanged } from 'rxjs/operators';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/abstract/abstract-map-api-loader.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class MapsAPILoader {
}
MapsAPILoader.decorators = [
    { type: Injectable }
];
if (false) {
    /**
     * @abstract
     * @return {?}
     */
    MapsAPILoader.prototype.load = function () { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/fitbounds.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FitBoundsService {
    /**
     * @param {?} loader
     */
    constructor(loader) {
        this.loader = loader;
        this._boundsChangeSampleTime$ = new BehaviorSubject(200);
        this._includeInBounds$ = new BehaviorSubject(new Map());
        this._fitBoundsDetails$ = new ReplaySubject(1);
        this.bounds$ = from(loader.load()).pipe(mergeMap((/**
         * @return {?}
         */
        () => this._includeInBounds$)), sample(this._boundsChangeSampleTime$.pipe(switchMap((/**
         * @param {?} time
         * @return {?}
         */
        (time) => timer(0, time))))), map((/**
         * @param {?} includeInBounds
         * @return {?}
         */
        (includeInBounds) => this.generateBounds(includeInBounds))), shareReplay(1));
    }
    /**
     * @return {?}
     */
    getFitBoundsDeta() {
        return this._fitBoundsDetails$.asObservable();
    }
    /**
     * @param {?} position
     * @return {?}
     */
    addToBounds(position) {
        /** @type {?} */
        const id = this.createIdentifier(position);
        if (this._includeInBounds$.value.has(id)) {
            return;
        }
        /** @type {?} */
        const mapBounds = this._includeInBounds$.value;
        mapBounds.set(id, position);
        this._includeInBounds$.next(mapBounds);
    }
    /**
     * @param {?} position
     * @return {?}
     */
    removeFromBounds(position) {
        /** @type {?} */
        const mapBounds = this._includeInBounds$.value;
        mapBounds.delete(this.createIdentifier(position));
        this._includeInBounds$.next(mapBounds);
    }
    /**
     * @param {?} position
     * @return {?}
     */
    createIdentifier(position) {
        return `${position[0]}+${position[1]}`;
    }
    /**
     * @param {?} timeMs
     * @return {?}
     */
    changeFitBoundsChangeSampleTime(timeMs) {
        this._boundsChangeSampleTime$.next(timeMs);
    }
    /**
     * @param {?} includeInBounds
     * @return {?}
     */
    generateBounds(includeInBounds) {
        return this._generateBounds(includeInBounds);
    }
    /**
     * @return {?}
     */
    getBounds() {
        return this.bounds$;
    }
    /**
     * @private
     * @param {?} includeInBounds
     * @return {?}
     */
    _generateBounds(includeInBounds) {
        /** @type {?} */
        const bounds = new google.maps.LatLngBounds();
        includeInBounds.forEach((/**
         * @param {?} b
         * @return {?}
         */
        (b) => bounds.extend(new google.maps.LatLng(b[0], b[1]))));
        return bounds;
    }
}
FitBoundsService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
FitBoundsService.ctorParameters = () => [
    { type: MapsAPILoader }
];
if (false) {
    /**
     * @type {?}
     * @protected
     */
    FitBoundsService.prototype.bounds$;
    /**
     * @type {?}
     * @protected
     */
    FitBoundsService.prototype._boundsChangeSampleTime$;
    /**
     * @type {?}
     * @protected
     */
    FitBoundsService.prototype._includeInBounds$;
    /** @type {?} */
    FitBoundsService.prototype._fitBoundsDetails$;
    /**
     * @type {?}
     * @protected
     */
    FitBoundsService.prototype.loader;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/map.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MapService {
    /**
     * @param {?} _loader
     * @param {?} _zone
     */
    constructor(_loader, _zone) {
        this._loader = _loader;
        this._zone = _zone;
        this.load$ = new BehaviorSubject(null);
    }
    /**
     * @return {?}
     */
    get container() {
        return this._container;
    }
    /**
     * @return {?}
     */
    getMap() {
        return this._map;
    }
    /**
     * @param {?} htmlElement
     * @param {?} opts
     * @return {?}
     */
    createMap(htmlElement, opts) {
        return new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        (observer) => {
            this._loader.load().pipe(take(1)).subscribe((/**
             * @return {?}
             */
            () => {
                this._map = this._zone.runOutsideAngular((/**
                 * @return {?}
                 */
                () => new google.maps.Map(htmlElement, opts)));
                this._container = htmlElement;
                observer.next();
            }));
        }));
    }
    /**
     * @param {?} bounds
     * @return {?}
     */
    fitBounds(bounds) {
        this._map.fitBounds(bounds);
    }
    /**
     * @return {?}
     */
    destroy() {
        google.maps.event.clearInstanceListeners(this._map);
    }
    /**
     * @return {?}
     */
    getMinZoom() {
        return this._map.get('minZoom');
    }
    /**
     * @return {?}
     */
    getMaxZoom() {
        return this._map.get('maxZoom');
    }
    /**
     * @param {?} zoom
     * @return {?}
     */
    setMinZoom(zoom) {
        this._map.setOptions({ minZoom: zoom });
    }
    /**
     * @param {?} zoom
     * @return {?}
     */
    setMaxZoom(zoom) {
        this._map.setOptions({ maxZoom: zoom });
    }
    /**
     * @return {?}
     */
    setZoomIn() {
        this._map.setZoom(this._map.getZoom() + 1);
    }
    /**
     * @return {?}
     */
    setZoomOut() {
        this._map.setZoom(this._map.getZoom() - 1);
    }
}
MapService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
MapService.ctorParameters = () => [
    { type: MapsAPILoader },
    { type: NgZone }
];
if (false) {
    /** @type {?} */
    MapService.prototype.load$;
    /**
     * @type {?}
     * @private
     */
    MapService.prototype._map;
    /**
     * @type {?}
     * @private
     */
    MapService.prototype._container;
    /**
     * @type {?}
     * @private
     */
    MapService.prototype._loader;
    /**
     * @type {?}
     * @private
     */
    MapService.prototype._zone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/event.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class EventService {
    /**
     * @param {?} _zone
     */
    constructor(_zone) {
        this._zone = _zone;
        this._pending = [];
    }
    /**
     * @template T
     * @param {?} name
     * @return {?}
     */
    getEventListener(name) {
        /** @type {?} */
        const observable$ = new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        (observer) => {
            if (!this._target) {
                this._pending.push({ observable: observable$, observer });
                return null;
            }
            this._target.addListener(name, (/**
             * @param {?} event
             * @return {?}
             */
            (event) => {
                this._zone.run((/**
                 * @return {?}
                 */
                () => observer.next(event)));
            }));
        }));
        return observable$;
    }
    /**
     * @param {?} target
     * @return {?}
     */
    setTarget(target) {
        if (target === this._target) {
            return;
        }
        if (this._target) {
            this._pending = [];
        }
        this._target = target;
        this._pending.forEach((/**
         * @param {?} subscriber
         * @return {?}
         */
        (subscriber) => subscriber.observable.subscribe(subscriber.observer)));
        this._pending = [];
    }
    /**
     * @return {?}
     */
    destroy() {
        this._pending = [];
        this._target = null;
    }
}
EventService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
EventService.ctorParameters = () => [
    { type: NgZone }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    EventService.prototype._pending;
    /**
     * @type {?}
     * @private
     */
    EventService.prototype._target;
    /**
     * @type {?}
     * @private
     */
    EventService.prototype._zone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/constanst/map-providers.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const PROVIDERS = [
    MapService,
    EventService,
    FitBoundsService,
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/map/map.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MapComponent {
    /**
     * @param {?} platformId
     * @param {?} _element
     * @param {?} mapService
     * @param {?} _eventService
     * @param {?} _fitBoundsService
     */
    constructor(platformId, _element, mapService, _eventService, _fitBoundsService) {
        this._element = _element;
        this.mapService = mapService;
        this._eventService = _eventService;
        this._fitBoundsService = _fitBoundsService;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.bounds_changed
         */
        this.boundsChanged = this._eventService.getEventListener('bounds_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.center_changed
         */
        this.centerChanged = this._eventService.getEventListener('center_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.click
         */
        this.mapClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.dblclick
         */
        this.mapDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.drag
         */
        this.mapDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.drag
         */
        this.mapDragend = this._eventService.getEventListener('dragend');
        /**
             * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.drag
             */
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.dragstart
         */
        this.mapDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.heading_changed
         */
        this.headingChanged = this._eventService.getEventListener('heading_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.idle
         */
        this.idle = this._eventService.getEventListener('idle');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.maptypeid_changed
         */
        this.maptypeidChanged = this._eventService.getEventListener('maptypeid_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mousemove
         */
        this.mapMousemove = this._eventService.getEventListener('mousemove');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mouseout
         */
        this.mapMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mouseover
         */
        this.mapMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.projection_changed
         */
        this.projectionChanged = this._eventService.getEventListener('projection_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.rightclick
         */
        this.mapRightclick = this._eventService.getEventListener('rightclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.tilesloaded
         */
        this.tilesloaded = this._eventService.getEventListener('tilesloaded');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.tilt_changed
         */
        this.tiltChanged = this._eventService.getEventListener('tilt_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.zoom_changed
         */
        this.zoomChanged = this._eventService.getEventListener('zoom_changed');
        this.mapReady = new Subject();
        this._destroy$ = new Subject();
        this._isBrowser = isPlatformBrowser(platformId);
    }
    /**
     * @return {?}
     */
    ngAfterContentInit() {
        this._onInit();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.map) {
            return;
        }
        changes.center
            && !changes.center.isFirstChange()
            && this.map.setCenter(this.center);
        changes.zoom
            && !changes.zoom.isFirstChange()
            && this.map.setZoom(this.zoom);
        changes.mapTypeId
            && !changes.mapTypeId.isFirstChange()
            && this.map.setOptions({ mapTypeId: this.mapTypeId });
        changes.options
            && !changes.options.isFirstChange()
            && this.map.setOptions(this._combineOptions());
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next(true);
        this._destroy$.complete();
        this._eventService.destroy();
        this.mapService.destroy();
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        if (!this._isBrowser) {
            return;
        }
        /** @type {?} */
        const createMap$ = this.mapService.createMap(this._getHTMLElement(), this._combineOptions());
        createMap$.subscribe((/**
         * @return {?}
         */
        () => {
            this.map = this.mapService.getMap();
            this._assertInitialized();
            this._eventService.setTarget(this.map);
            this.mapReady.next();
            this.mapService.load$.next(true);
        }));
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { zoom: this.zoom || this.options.zoom, center: this.center || this.options.center, mapTypeId: this.mapTypeId || this.options.mapTypeId });
    }
    /**
     * @private
     * @return {?}
     */
    _getHTMLElement() {
        return this._element.nativeElement.querySelector('.c-dex-map-container');
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this.map) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
    }
}
MapComponent.decorators = [
    { type: Component, args: [{
                selector: 'dgm-map',
                providers: PROVIDERS,
                template: "<div class=\"c-dex-map\">\n    <div #container class=\"c-dex-map-container\"></div>\n    <div class=\"map-content\">\n        <ng-content></ng-content>\n    </div>\n</div>",
                encapsulation: ViewEncapsulation.None,
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".c-dex-map{background-color:#f5f5f5!important;font-family:Roboto,Helvetica Neue,sans-serif;height:100%;overflow:hidden;position:relative;width:100%}.c-dex-map .map-container-inner{height:inherit;width:inherit}.c-dex-map .map-container-inner div{background-repeat:no-repeat}.c-dex-map .map-content{display:none}.c-dex-map .c-dex-map-container{height:100%;position:relative;width:100%;z-index:1}.c-dex-map .c-h21-map-toolbar-horizontal{box-sizing:border-box;display:flex;flex-direction:row;height:72px;left:0;padding:16px;pointer-events:none;position:absolute;top:0;width:100%;z-index:3}.c-dex-map .c-h21-map-toolbar-horizontal.c-h21-map-toolbar-horizontal__bottom{bottom:0;padding:16px 72px 16px 16px;top:auto}.c-dex-map .c-h21-map-toolbar-horizontal>:not(.flex-fill){pointer-events:auto}"]
            }] }
];
/** @nocollapse */
MapComponent.ctorParameters = () => [
    { type: Object, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] },
    { type: ElementRef },
    { type: MapService },
    { type: EventService },
    { type: FitBoundsService }
];
MapComponent.propDecorators = {
    center: [{ type: Input }],
    mapTypeId: [{ type: Input }],
    zoom: [{ type: Input }],
    options: [{ type: Input }],
    boundsChanged: [{ type: Output }],
    centerChanged: [{ type: Output }],
    mapClick: [{ type: Output }],
    mapDblclick: [{ type: Output }],
    mapDrag: [{ type: Output }],
    mapDragend: [{ type: Output }],
    mapDragstart: [{ type: Output }],
    headingChanged: [{ type: Output }],
    idle: [{ type: Output }],
    maptypeidChanged: [{ type: Output }],
    mapMousemove: [{ type: Output }],
    mapMouseout: [{ type: Output }],
    mapMouseover: [{ type: Output }],
    projectionChanged: [{ type: Output }],
    mapRightclick: [{ type: Output }],
    tilesloaded: [{ type: Output }],
    tiltChanged: [{ type: Output }],
    zoomChanged: [{ type: Output }],
    mapReady: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#MapOptions.center
     * @type {?}
     */
    MapComponent.prototype.center;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#MapOptions.mapTypeId
     * @type {?}
     */
    MapComponent.prototype.mapTypeId;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#MapOptions.zoom
     * @type {?}
     */
    MapComponent.prototype.zoom;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#MapOptions
     * @type {?}
     */
    MapComponent.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.bounds_changed
     * @type {?}
     */
    MapComponent.prototype.boundsChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.center_changed
     * @type {?}
     */
    MapComponent.prototype.centerChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.click
     * @type {?}
     */
    MapComponent.prototype.mapClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.dblclick
     * @type {?}
     */
    MapComponent.prototype.mapDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.drag
     * @type {?}
     */
    MapComponent.prototype.mapDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.drag
     * @type {?}
     */
    MapComponent.prototype.mapDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.dragstart
     * @type {?}
     */
    MapComponent.prototype.mapDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.heading_changed
     * @type {?}
     */
    MapComponent.prototype.headingChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.idle
     * @type {?}
     */
    MapComponent.prototype.idle;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.maptypeid_changed
     * @type {?}
     */
    MapComponent.prototype.maptypeidChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mousemove
     * @type {?}
     */
    MapComponent.prototype.mapMousemove;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mouseout
     * @type {?}
     */
    MapComponent.prototype.mapMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.mouseover
     * @type {?}
     */
    MapComponent.prototype.mapMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.projection_changed
     * @type {?}
     */
    MapComponent.prototype.projectionChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.rightclick
     * @type {?}
     */
    MapComponent.prototype.mapRightclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.tilesloaded
     * @type {?}
     */
    MapComponent.prototype.tilesloaded;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.tilt_changed
     * @type {?}
     */
    MapComponent.prototype.tiltChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map.zoom_changed
     * @type {?}
     */
    MapComponent.prototype.zoomChanged;
    /** @type {?} */
    MapComponent.prototype.mapReady;
    /**
     * The underlying google.maps.Map object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Map
     * @type {?}
     */
    MapComponent.prototype.map;
    /**
     * @type {?}
     * @private
     */
    MapComponent.prototype._isBrowser;
    /**
     * @type {?}
     * @private
     */
    MapComponent.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    MapComponent.prototype._element;
    /** @type {?} */
    MapComponent.prototype.mapService;
    /**
     * @type {?}
     * @private
     */
    MapComponent.prototype._eventService;
    /**
     * @type {?}
     * @protected
     */
    MapComponent.prototype._fitBoundsService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/components/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/constanst/api-config.constants.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const API_CONFIG = new InjectionToken('dgm MAPS_API_CONFIG');

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/window-ref.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class WindowRef {
    /**
     * @return {?}
     */
    getNativeWindow() {
        return window;
    }
}
WindowRef.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/document-ref.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DocumentRef {
    /**
     * @return {?}
     */
    getNativeDocument() {
        return document;
    }
}
DocumentRef.decorators = [
    { type: Injectable }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/constanst/browser-providers.constants.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const BROWSER_PROVIDERS = [WindowRef, DocumentRef];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/constanst/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/bicycling-layer/bicycling-layer.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Bicycling Layer via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/map#BicyclingLayer
 */
class BicyclingLayerDirective {
    /**
     * @param {?} _mapService
     */
    constructor(_mapService) {
        this._mapService = _mapService;
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.bicyclingLayer && this.bicyclingLayer.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this.bicyclingLayer = new google.maps.BicyclingLayer();
        this._assertInitialized();
        this.bicyclingLayer.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.bicyclingLayer) {
            throw Error('Cannot interact with a Google Map Bicycling Layer before it has been initialized. ' +
                'Please wait for the Bicycling Layer to load before trying to interact with it.');
        }
    }
}
BicyclingLayerDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmBicyclingLayer]' },] }
];
/** @nocollapse */
BicyclingLayerDirective.ctorParameters = () => [
    { type: MapService }
];
if (false) {
    /**
     * The underlying google.maps.BicyclingLayer object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#BicyclingLayer
     * @type {?}
     */
    BicyclingLayerDirective.prototype.bicyclingLayer;
    /**
     * @type {?}
     * @private
     */
    BicyclingLayerDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    BicyclingLayerDirective.prototype._mapService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/circle/circle.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Circle via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle
 */
class CircleDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.center_changed
         */
        this.centerChanged = this._eventService.getEventListener('center_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.click
         */
        this.circleClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dblclick
         */
        this.circleDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.drag
         */
        this.circleDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragend
         */
        this.circleDragend = this._eventService.getEventListener('dragend');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragstart
         */
        this.circleDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousedown
         */
        this.circleMousedown = this._eventService.getEventListener('mousedown');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousemove
         */
        this.circleMousemove = this._eventService.getEventListener('mousemove');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseout
         */
        this.circleMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseover
         */
        this.circleMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseup
         */
        this.circleMouseup = this._eventService.getEventListener('mouseup');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.radius_changed
         */
        this.radiusChanged = this._eventService.getEventListener('radius_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.rightclick
         */
        this.circleRightclick = this._eventService.getEventListener('rightclick');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.circle) {
            return;
        }
        changes.center
            && !changes.center.isFirstChange()
            && this.circle.setCenter(this.center);
        changes.draggable
            && !changes.draggable.isFirstChange()
            && this.circle.setDraggable(this.draggable);
        changes.editable
            && !changes.editable.isFirstChange()
            && this.circle.setEditable(this.editable);
        changes.radius
            && !changes.radius.isFirstChange()
            && this.circle.setRadius(this.radius);
        changes.options
            && !changes.options.isFirstChange()
            && this.circle.setOptions(this._combineOptions());
        changes.visible
            && !changes.visible.isFirstChange()
            && this.circle.setVisible(this.visible);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.circle && this.circle.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.circle = new google.maps.Circle(this._combineOptions());
        }));
        this._assertInitialized();
        this.circle.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { center: this.center || this.options.center, draggable: this.draggable || this.options.draggable || false, editable: this.editable || this.options.editable || true, radius: this.radius || this.options.radius, visible: this.visible || this.options.visible || true });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.circle) {
            throw Error('Cannot interact with a Google Map Marker before it has been initialized. ' +
                'Please wait for the Circle to load before trying to interact with it.');
        }
    }
}
CircleDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmCircle]' },] }
];
/** @nocollapse */
CircleDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
CircleDirective.propDecorators = {
    center: [{ type: Input }],
    draggable: [{ type: Input }],
    editable: [{ type: Input }],
    radius: [{ type: Input }],
    options: [{ type: Input }],
    visible: [{ type: Input }],
    centerChanged: [{ type: Output }],
    circleClick: [{ type: Output }],
    circleDblclick: [{ type: Output }],
    circleDrag: [{ type: Output }],
    circleDragend: [{ type: Output }],
    circleDragstart: [{ type: Output }],
    circleMousedown: [{ type: Output }],
    circleMousemove: [{ type: Output }],
    circleMouseout: [{ type: Output }],
    circleMouseover: [{ type: Output }],
    circleMouseup: [{ type: Output }],
    radiusChanged: [{ type: Output }],
    circleRightclick: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.center
     * @type {?}
     */
    CircleDirective.prototype.center;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.draggable
     * @type {?}
     */
    CircleDirective.prototype.draggable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.editable
     * @type {?}
     */
    CircleDirective.prototype.editable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.radius
     * @type {?}
     */
    CircleDirective.prototype.radius;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions
     * @type {?}
     */
    CircleDirective.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.visible
     * @type {?}
     */
    CircleDirective.prototype.visible;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.center_changed
     * @type {?}
     */
    CircleDirective.prototype.centerChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.click
     * @type {?}
     */
    CircleDirective.prototype.circleClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dblclick
     * @type {?}
     */
    CircleDirective.prototype.circleDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.drag
     * @type {?}
     */
    CircleDirective.prototype.circleDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragend
     * @type {?}
     */
    CircleDirective.prototype.circleDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragstart
     * @type {?}
     */
    CircleDirective.prototype.circleDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousedown
     * @type {?}
     */
    CircleDirective.prototype.circleMousedown;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousemove
     * @type {?}
     */
    CircleDirective.prototype.circleMousemove;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseout
     * @type {?}
     */
    CircleDirective.prototype.circleMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseover
     * @type {?}
     */
    CircleDirective.prototype.circleMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseup
     * @type {?}
     */
    CircleDirective.prototype.circleMouseup;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.radius_changed
     * @type {?}
     */
    CircleDirective.prototype.radiusChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.rightclick
     * @type {?}
     */
    CircleDirective.prototype.circleRightclick;
    /**
     * The underlying google.maps.Circle object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle
     * @type {?}
     */
    CircleDirective.prototype.circle;
    /**
     * @type {?}
     * @private
     */
    CircleDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    CircleDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    CircleDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    CircleDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/abstract/abstract-map-fitbounds-accessor.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 */
class FitBoundsAccessor {
}
FitBoundsAccessor.decorators = [
    { type: Injectable }
];
if (false) {
    /**
     * @abstract
     * @return {?}
     */
    FitBoundsAccessor.prototype.getFitBounds = function () { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/fitbounds/fitbounds.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// interfaces
class FitBoundsDirective {
    /**
     * @param {?} _fitBoundsAccessor
     * @param {?} _fitBoundsService
     */
    constructor(_fitBoundsAccessor, _fitBoundsService) {
        this._fitBoundsAccessor = _fitBoundsAccessor;
        this._fitBoundsService = _fitBoundsService;
        this.dexFitBounds = true;
        this._destroyed$ = new Subject();
        this._latestFitBoundsDetails = null;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._fitBoundsAccessor
            .getFitBounds()
            .pipe(distinctUntilChanged((/**
         * @param {?} x
         * @param {?} y
         * @return {?}
         */
        (x, y) => x.position[0] === y.position[0] && x.position[1] === y.position[1])), takeUntil(this._destroyed$))
            .subscribe((/**
         * @param {?} details
         * @return {?}
         */
        (details) => this._updateBounds(details)));
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this._updateBounds();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroyed$.next();
        this._destroyed$.complete();
        this._latestFitBoundsDetails && this._fitBoundsService.removeFromBounds(this._latestFitBoundsDetails.position);
    }
    /**
     * @private
     * @param {?=} newFitBoundsDetails
     * @return {?}
     */
    _updateBounds(newFitBoundsDetails) {
        this._latestFitBoundsDetails && this._fitBoundsService.removeFromBounds(this._latestFitBoundsDetails.position);
        if (newFitBoundsDetails) {
            this._latestFitBoundsDetails = newFitBoundsDetails;
        }
        if (!this._latestFitBoundsDetails) {
            return;
        }
        this.dexFitBounds && this._fitBoundsService.addToBounds(this._latestFitBoundsDetails.position);
    }
}
FitBoundsDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmFitBounds]' },] }
];
/** @nocollapse */
FitBoundsDirective.ctorParameters = () => [
    { type: FitBoundsAccessor, decorators: [{ type: Self }] },
    { type: FitBoundsService }
];
FitBoundsDirective.propDecorators = {
    dexFitBounds: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    FitBoundsDirective.prototype.dexFitBounds;
    /**
     * @type {?}
     * @private
     */
    FitBoundsDirective.prototype._destroyed$;
    /**
     * @type {?}
     * @private
     */
    FitBoundsDirective.prototype._latestFitBoundsDetails;
    /**
     * @type {?}
     * @private
     */
    FitBoundsDirective.prototype._fitBoundsAccessor;
    /**
     * @type {?}
     * @private
     */
    FitBoundsDirective.prototype._fitBoundsService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/ground-overlay/ground-overlay.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Ground Overlay via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
 */
class GroundOverlayDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay.click
         */
        this.groundOverlayClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay
         * #GroundOverlay.dblclick
         */
        this.groundOverlayDblclick = this._eventService.getEventListener('dblclick');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        changes.opacity
            && !changes.opacity.isFirstChange()
            && this.groundOverlay.setOpacity(this.opacity);
        changes.url
            && !changes.url.isFirstChange()
            && this._urlChanges();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.groundOverlay && this.groundOverlay.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        if (!this.bounds) {
            return;
        }
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.groundOverlay = new google.maps.GroundOverlay(this.url, this.bounds, this._combineOptions());
        }));
        this._assertInitialized();
        this.groundOverlay.setMap(this._mapService.getMap());
        this._eventService.setTarget(this.groundOverlay);
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return {
            clickable: this.clickable || true,
            opacity: this.opacity || null,
        };
    }
    /**
     * @private
     * @return {?}
     */
    _urlChanges() {
        this.groundOverlay.set('url', this.url);
        this.groundOverlay.setMap(null);
        this.groundOverlay.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.groundOverlay) {
            throw Error('Cannot interact with a Google Map Ground Overlay before it has been initialized. ' +
                'Please wait for the Ground Overlay to load before trying to interact with it.');
        }
    }
}
GroundOverlayDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmGroundOverlay]' },] }
];
/** @nocollapse */
GroundOverlayDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
GroundOverlayDirective.propDecorators = {
    bounds: [{ type: Input }],
    url: [{ type: Input }],
    clickable: [{ type: Input }],
    opacity: [{ type: Input }],
    groundOverlayClick: [{ type: Output }],
    groundOverlayDblclick: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     * @type {?}
     */
    GroundOverlayDirective.prototype.bounds;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     * @type {?}
     */
    GroundOverlayDirective.prototype.url;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlayOptions.clickable
     * @type {?}
     */
    GroundOverlayDirective.prototype.clickable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlayOptions.opacity
     * @type {?}
     */
    GroundOverlayDirective.prototype.opacity;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay.click
     * @type {?}
     */
    GroundOverlayDirective.prototype.groundOverlayClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay
     * #GroundOverlay.dblclick
     * @type {?}
     */
    GroundOverlayDirective.prototype.groundOverlayDblclick;
    /**
     * The underlying google.maps.GroundOverlay object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     * @type {?}
     */
    GroundOverlayDirective.prototype.groundOverlay;
    /**
     * @type {?}
     * @private
     */
    GroundOverlayDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    GroundOverlayDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    GroundOverlayDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    GroundOverlayDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/kml-layer/kml-layer.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Kml Layer via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer
 */
class KmlLayerDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/kml
         * #KmlLayer.defaultviewport_changed
         */
        this.defaultviewportChanged = this._eventService.getEventListener('defaultviewport_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer.status_changed
         */
        this.statusChanged = this._eventService.getEventListener('status_changed');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.kmlLayer) {
            return;
        }
        changes.options
            && !changes.options.isFirstChange()
            && this.kmlLayer.setOptions(this._combineOptions());
        changes.url
            && !changes.url.isFirstChange()
            && this.kmlLayer.setUrl(this.url);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.kmlLayer && this.kmlLayer.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.kmlLayer = new google.maps.KmlLayer(this._combineOptions());
        }));
        this._assertInitialized();
        this.kmlLayer.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { url: this.url || this.options.url });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.kmlLayer) {
            throw Error('Cannot interact with a Google Map Kml Layer before it has been initialized. ' +
                'Please wait for the Kml Layer to load before trying to interact with it.');
        }
    }
}
KmlLayerDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmKmlLayer]' },] }
];
/** @nocollapse */
KmlLayerDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
KmlLayerDirective.propDecorators = {
    options: [{ type: Input }],
    url: [{ type: Input }],
    defaultviewportChanged: [{ type: Output }],
    statusChanged: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayerOptions
     * @type {?}
     */
    KmlLayerDirective.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayerOptions.url
     * @type {?}
     */
    KmlLayerDirective.prototype.url;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml
     * #KmlLayer.defaultviewport_changed
     * @type {?}
     */
    KmlLayerDirective.prototype.defaultviewportChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer.status_changed
     * @type {?}
     */
    KmlLayerDirective.prototype.statusChanged;
    /**
     * The underlying google.maps.KmlLayer object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer
     * @type {?}
     */
    KmlLayerDirective.prototype.kmlLayer;
    /**
     * @type {?}
     * @private
     */
    KmlLayerDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    KmlLayerDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    KmlLayerDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    KmlLayerDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/marker/marker.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Marker via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/map#Marker
 */
class MarkerDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dblclick
         */
        this.markerDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.drag
         */
        this.markerDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragend
         */
        this.markerDragend = this._eventService.getEventListener('dragend');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.draggable_changed
         */
        this.draggableChanged = this._eventService.getEventListener('draggable_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragstart
         */
        this.markerDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.flat_changed
         */
        this.flatChanged = this._eventService.getEventListener('flat_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.icon_changed
         */
        this.iconChanged = this._eventService.getEventListener('icon_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mousedown
         */
        this.markerMousedown = this._eventService.getEventListener('mousedown');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseout
         */
        this.markerMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseover
         */
        this.markerMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseup
         */
        this.markerMouseup = this._eventService.getEventListener('mouseup');
        /**
         * See developers.google.com/maps/documentation/javascript/reference/marker#Marker.position_changed
         */
        this.positionChanged = this._eventService.getEventListener('position_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.rightclick
         */
        this.markerRightclick = this._eventService.getEventListener('rightclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.shape_changed
         */
        this.shapeChanged = this._eventService.getEventListener('shape_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.title_changed
         */
        this.titleChanged = this._eventService.getEventListener('title_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.visible_changed
         */
        this.visibleChanged = this._eventService.getEventListener('visible_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.zindex_changed
         */
        this.zindexChanged = this._eventService.getEventListener('zindex_changed');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.marker) {
            return;
        }
        changes.clickable
            && !changes.clickable.isFirstChange()
            && this.marker.setClickable(this.clickable);
        changes.draggable
            && !changes.draggable.isFirstChange()
            && this.marker.setDraggable(this.draggable);
        changes.label
            && !changes.label.isFirstChange()
            && this.marker.setLabel(this.label);
        changes.position
            && !changes.position.isFirstChange()
            && this.marker.setPosition(this.position);
        changes.options
            && !changes.options.isFirstChange()
            && this.marker.setOptions(this._combineOptions());
        changes.title
            && !changes.title.isFirstChange()
            && this.marker.setTitle(this.title);
        changes.visible
            && !changes.visible.isFirstChange()
            && this.marker.setVisible(this.visible);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.marker && this.marker.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.marker = new google.maps.Marker(this._combineOptions());
        }));
        this._assertInitialized();
        this.marker.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { clickable: this.clickable || this.options.clickable || true, draggable: this.draggable || this.options.draggable || false, label: this.label || this.options.label || null, position: this.position || this.options.position, title: this.title || this.options.title || null, visible: this.visible || this.options.visible || true });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.marker) {
            throw Error('Cannot interact with a Google Map Marker before it has been initialized. ' +
                'Please wait for the Marker to load before trying to interact with it.');
        }
    }
}
MarkerDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmMarker]' },] }
];
/** @nocollapse */
MarkerDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
MarkerDirective.propDecorators = {
    clickable: [{ type: Input }],
    draggable: [{ type: Input }],
    label: [{ type: Input }],
    position: [{ type: Input }],
    options: [{ type: Input }],
    title: [{ type: Input }],
    visible: [{ type: Input }],
    markerDblclick: [{ type: Output }],
    markerDrag: [{ type: Output }],
    markerDragend: [{ type: Output }],
    draggableChanged: [{ type: Output }],
    markerDragstart: [{ type: Output }],
    flatChanged: [{ type: Output }],
    iconChanged: [{ type: Output }],
    markerMousedown: [{ type: Output }],
    markerMouseout: [{ type: Output }],
    markerMouseover: [{ type: Output }],
    markerMouseup: [{ type: Output }],
    positionChanged: [{ type: Output }],
    markerRightclick: [{ type: Output }],
    shapeChanged: [{ type: Output }],
    titleChanged: [{ type: Output }],
    visibleChanged: [{ type: Output }],
    zindexChanged: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.clickable
     * @type {?}
     */
    MarkerDirective.prototype.clickable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.draggable
     * @type {?}
     */
    MarkerDirective.prototype.draggable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.label
     * @type {?}
     */
    MarkerDirective.prototype.label;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.position
     * @type {?}
     */
    MarkerDirective.prototype.position;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions
     * @type {?}
     */
    MarkerDirective.prototype.options;
    /**
     * See developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.title
     * @type {?}
     */
    MarkerDirective.prototype.title;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.visible
     * @type {?}
     */
    MarkerDirective.prototype.visible;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dblclick
     * @type {?}
     */
    MarkerDirective.prototype.markerDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.drag
     * @type {?}
     */
    MarkerDirective.prototype.markerDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragend
     * @type {?}
     */
    MarkerDirective.prototype.markerDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.draggable_changed
     * @type {?}
     */
    MarkerDirective.prototype.draggableChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragstart
     * @type {?}
     */
    MarkerDirective.prototype.markerDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.flat_changed
     * @type {?}
     */
    MarkerDirective.prototype.flatChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.icon_changed
     * @type {?}
     */
    MarkerDirective.prototype.iconChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mousedown
     * @type {?}
     */
    MarkerDirective.prototype.markerMousedown;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseout
     * @type {?}
     */
    MarkerDirective.prototype.markerMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseover
     * @type {?}
     */
    MarkerDirective.prototype.markerMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseup
     * @type {?}
     */
    MarkerDirective.prototype.markerMouseup;
    /**
     * See developers.google.com/maps/documentation/javascript/reference/marker#Marker.position_changed
     * @type {?}
     */
    MarkerDirective.prototype.positionChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.rightclick
     * @type {?}
     */
    MarkerDirective.prototype.markerRightclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.shape_changed
     * @type {?}
     */
    MarkerDirective.prototype.shapeChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.title_changed
     * @type {?}
     */
    MarkerDirective.prototype.titleChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.visible_changed
     * @type {?}
     */
    MarkerDirective.prototype.visibleChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.zindex_changed
     * @type {?}
     */
    MarkerDirective.prototype.zindexChanged;
    /**
     * The underlying google.maps.Marker object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Marker
     * @type {?}
     */
    MarkerDirective.prototype.marker;
    /**
     * @type {?}
     * @private
     */
    MarkerDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    MarkerDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    MarkerDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    MarkerDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/polygon/polygon.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Polygon via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon
 */
class PolygonDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.click
         */
        this.polygonClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dblclick
         */
        this.polygonDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.drag
         */
        this.polygonDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragend
         */
        this.polygonDragend = this._eventService.getEventListener('dragend');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragstart
         */
        this.polygonDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousedown
         */
        this.polygonMousedown = this._eventService.getEventListener('mousedown');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousemove
         */
        this.polygonMousemove = this._eventService.getEventListener('mousemove');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseout
         */
        this.polygonMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseover
         */
        this.polygonMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseup
         */
        this.polygonMouseup = this._eventService.getEventListener('mouseup');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.rightclick
         */
        this.polygonRightclick = this._eventService.getEventListener('rightclick');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.polygon) {
            return;
        }
        changes.draggable
            && !changes.draggable.isFirstChange()
            && this.polygon.setDraggable(this.draggable);
        changes.editable
            && !changes.editable.isFirstChange()
            && this.polygon.setEditable(this.editable);
        changes.options
            && !changes.options.isFirstChange()
            && this.polygon.setOptions(this._combineOptions());
        changes.paths
            && !changes.paths.isFirstChange()
            && this.polygon.setPaths(this.paths);
        changes.visible
            && !changes.visible.isFirstChange()
            && this.polygon.setVisible(this.visible);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.polygon && this.polygon.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.polygon = new google.maps.Polygon(this._combineOptions());
        }));
        this._assertInitialized();
        this.polygon.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { draggable: this.draggable || this.options.draggable || false, editable: this.editable || this.options.editable || true, paths: this.paths || this.options.paths, visible: this.visible || this.options.visible || true });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.polygon) {
            throw Error('Cannot interact with a Google Map Polygon before it has been initialized. ' +
                'Please wait for the Polygon to load before trying to interact with it.');
        }
    }
}
PolygonDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmPolygon]' },] }
];
/** @nocollapse */
PolygonDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
PolygonDirective.propDecorators = {
    draggable: [{ type: Input }],
    editable: [{ type: Input }],
    options: [{ type: Input }],
    paths: [{ type: Input }],
    visible: [{ type: Input }],
    polygonClick: [{ type: Output }],
    polygonDblclick: [{ type: Output }],
    polygonDrag: [{ type: Output }],
    polygonDragend: [{ type: Output }],
    polygonDragstart: [{ type: Output }],
    polygonMousedown: [{ type: Output }],
    polygonMousemove: [{ type: Output }],
    polygonMouseout: [{ type: Output }],
    polygonMouseover: [{ type: Output }],
    polygonMouseup: [{ type: Output }],
    polygonRightclick: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.draggable
     * @type {?}
     */
    PolygonDirective.prototype.draggable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.editable
     * @type {?}
     */
    PolygonDirective.prototype.editable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions
     * @type {?}
     */
    PolygonDirective.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.paths
     * @type {?}
     */
    PolygonDirective.prototype.paths;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.visible
     * @type {?}
     */
    PolygonDirective.prototype.visible;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.click
     * @type {?}
     */
    PolygonDirective.prototype.polygonClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dblclick
     * @type {?}
     */
    PolygonDirective.prototype.polygonDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.drag
     * @type {?}
     */
    PolygonDirective.prototype.polygonDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragend
     * @type {?}
     */
    PolygonDirective.prototype.polygonDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragstart
     * @type {?}
     */
    PolygonDirective.prototype.polygonDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousedown
     * @type {?}
     */
    PolygonDirective.prototype.polygonMousedown;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousemove
     * @type {?}
     */
    PolygonDirective.prototype.polygonMousemove;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseout
     * @type {?}
     */
    PolygonDirective.prototype.polygonMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseover
     * @type {?}
     */
    PolygonDirective.prototype.polygonMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseup
     * @type {?}
     */
    PolygonDirective.prototype.polygonMouseup;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.rightclick
     * @type {?}
     */
    PolygonDirective.prototype.polygonRightclick;
    /**
     * The underlying google.maps.Polygon object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon
     * @type {?}
     */
    PolygonDirective.prototype.polygon;
    /**
     * @type {?}
     * @private
     */
    PolygonDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    PolygonDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    PolygonDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    PolygonDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/polyline/polyline.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Polyline via the Google Maps JavaScript API.
 *
 * See developers.google.com/maps/documentation/javascript/reference/polygon#Polyline
 */
class PolylineDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.click
         */
        this.polylineClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dblclick
         */
        this.polylineDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.drag
         */
        this.polylineDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragend
         */
        this.polylineDragend = this._eventService.getEventListener('dragend');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragstart
         */
        this.polylineDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousedown
         */
        this.polylineMousedown = this._eventService.getEventListener('mousedown');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousemove
         */
        this.polylineMousemove = this._eventService.getEventListener('mousemove');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseout
         */
        this.polylineMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseover
         */
        this.polylineMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseup
         */
        this.polylineMouseup = this._eventService.getEventListener('mouseup');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.rightclick
         */
        this.polylineRightclick = this._eventService.getEventListener('rightclick');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.polyline) {
            return;
        }
        changes.draggable
            && !changes.draggable.isFirstChange()
            && this.polyline.setDraggable(this.draggable);
        changes.editable
            && !changes.editable.isFirstChange()
            && this.polyline.setEditable(this.editable);
        changes.options
            && !changes.options.isFirstChange()
            && this.polyline.setOptions(this._combineOptions());
        changes.path
            && !changes.path.isFirstChange()
            && this.polyline.setPath(this.path);
        changes.visible
            && !changes.visible.isFirstChange()
            && this.polyline.setVisible(this.visible);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.polyline && this.polyline.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.polyline = new google.maps.Polyline(this._combineOptions());
        }));
        this._assertInitialized();
        this.polyline.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { visible: this.visible || this.options.visible || true, path: this.path || this.options.path, editable: this.editable || this.options.editable || true, draggable: this.draggable || this.options.draggable || false });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.polyline) {
            throw Error('Cannot interact with a Google Map Polyline before it has been initialized. ' +
                'Please wait for the Polyline to load before trying to interact with it.');
        }
    }
}
PolylineDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmPolyline]' },] }
];
/** @nocollapse */
PolylineDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
PolylineDirective.propDecorators = {
    draggable: [{ type: Input }],
    editable: [{ type: Input }],
    options: [{ type: Input }],
    path: [{ type: Input }],
    visible: [{ type: Input }],
    polylineClick: [{ type: Output }],
    polylineDblclick: [{ type: Output }],
    polylineDrag: [{ type: Output }],
    polylineDragend: [{ type: Output }],
    polylineDragstart: [{ type: Output }],
    polylineMousedown: [{ type: Output }],
    polylineMousemove: [{ type: Output }],
    polylineMouseout: [{ type: Output }],
    polylineMouseover: [{ type: Output }],
    polylineMouseup: [{ type: Output }],
    polylineRightclick: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.draggable
     * @type {?}
     */
    PolylineDirective.prototype.draggable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.editable
     * @type {?}
     */
    PolylineDirective.prototype.editable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions
     * @type {?}
     */
    PolylineDirective.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.path
     * @type {?}
     */
    PolylineDirective.prototype.path;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.visible
     * @type {?}
     */
    PolylineDirective.prototype.visible;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.click
     * @type {?}
     */
    PolylineDirective.prototype.polylineClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dblclick
     * @type {?}
     */
    PolylineDirective.prototype.polylineDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.drag
     * @type {?}
     */
    PolylineDirective.prototype.polylineDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragend
     * @type {?}
     */
    PolylineDirective.prototype.polylineDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragstart
     * @type {?}
     */
    PolylineDirective.prototype.polylineDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousedown
     * @type {?}
     */
    PolylineDirective.prototype.polylineMousedown;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousemove
     * @type {?}
     */
    PolylineDirective.prototype.polylineMousemove;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseout
     * @type {?}
     */
    PolylineDirective.prototype.polylineMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseover
     * @type {?}
     */
    PolylineDirective.prototype.polylineMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseup
     * @type {?}
     */
    PolylineDirective.prototype.polylineMouseup;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.rightclick
     * @type {?}
     */
    PolylineDirective.prototype.polylineRightclick;
    /**
     * The underlying google.maps.Polyline object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline
     * @type {?}
     */
    PolylineDirective.prototype.polyline;
    /**
     * @type {?}
     * @private
     */
    PolylineDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    PolylineDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    PolylineDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    PolylineDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/rectangle/rectangle.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Rectangle via the Google Maps JavaScript API.
 *
 * See developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle
 */
class RectangleDirective {
    /**
     * @param {?} _mapService
     * @param {?} _eventService
     * @param {?} _ngZone
     */
    constructor(_mapService, _eventService, _ngZone) {
        this._mapService = _mapService;
        this._eventService = _eventService;
        this._ngZone = _ngZone;
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.boundsChanged
         */
        this.boundsChanged = this._eventService.getEventListener('bounds_changed');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.click
         */
        this.rectangleClick = this._eventService.getEventListener('click');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dblclick
         */
        this.rectangleDblclick = this._eventService.getEventListener('dblclick');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.drag
         */
        this.rectangleDrag = this._eventService.getEventListener('drag');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragend
         */
        this.rectangleDragend = this._eventService.getEventListener('dragend');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragstart
         */
        this.rectangleDragstart = this._eventService.getEventListener('dragstart');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousedown
         */
        this.rectangleMousedown = this._eventService.getEventListener('mousedown');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousemove
         */
        this.rectangleMousemove = this._eventService.getEventListener('mousemove');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseout
         */
        this.rectangleMouseout = this._eventService.getEventListener('mouseout');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseover
         */
        this.rectangleMouseover = this._eventService.getEventListener('mouseover');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseup
         */
        this.rectangleMouseup = this._eventService.getEventListener('mouseup');
        /**
         * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.rightclick
         */
        this.rectangleRightclick = this._eventService.getEventListener('rightclick');
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (!this.restangle) {
            return;
        }
        changes.bounds
            && !changes.bounds.isFirstChange()
            && this.restangle.setBounds(this.bounds);
        changes.draggable
            && !changes.draggable.isFirstChange()
            && this.restangle.setDraggable(this.draggable);
        changes.editable
            && !changes.editable.isFirstChange()
            && this.restangle.setEditable(this.editable);
        changes.options
            && !changes.options.isFirstChange()
            && this.restangle.setOptions(this._combineOptions());
        changes.visible
            && !changes.visible.isFirstChange()
            && this.restangle.setVisible(this.visible);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.restangle && this.restangle.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.restangle = new google.maps.Rectangle(this._combineOptions());
        }));
        this._assertInitialized();
        this.restangle.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return Object.assign(Object.assign({}, this.options), { visible: this.visible || this.options.visible || true, bounds: this.bounds || this.options.bounds, editable: this.editable || this.options.editable || true, draggable: this.draggable || this.options.draggable || false });
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.restangle) {
            throw Error('Cannot interact with a Google Map Rectangle before it has been initialized. ' +
                'Please wait for the Rectangle to load before trying to interact with it.');
        }
    }
}
RectangleDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmRectangle]' },] }
];
/** @nocollapse */
RectangleDirective.ctorParameters = () => [
    { type: MapService },
    { type: EventService },
    { type: NgZone }
];
RectangleDirective.propDecorators = {
    bounds: [{ type: Input }],
    draggable: [{ type: Input }],
    editable: [{ type: Input }],
    options: [{ type: Input }],
    visible: [{ type: Input }],
    boundsChanged: [{ type: Output }],
    rectangleClick: [{ type: Output }],
    rectangleDblclick: [{ type: Output }],
    rectangleDrag: [{ type: Output }],
    rectangleDragend: [{ type: Output }],
    rectangleDragstart: [{ type: Output }],
    rectangleMousedown: [{ type: Output }],
    rectangleMousemove: [{ type: Output }],
    rectangleMouseout: [{ type: Output }],
    rectangleMouseover: [{ type: Output }],
    rectangleMouseup: [{ type: Output }],
    rectangleRightclick: [{ type: Output }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.bounds
     * @type {?}
     */
    RectangleDirective.prototype.bounds;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.draggable
     * @type {?}
     */
    RectangleDirective.prototype.draggable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.editable
     * @type {?}
     */
    RectangleDirective.prototype.editable;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions
     * @type {?}
     */
    RectangleDirective.prototype.options;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.visible
     * @type {?}
     */
    RectangleDirective.prototype.visible;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.boundsChanged
     * @type {?}
     */
    RectangleDirective.prototype.boundsChanged;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.click
     * @type {?}
     */
    RectangleDirective.prototype.rectangleClick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dblclick
     * @type {?}
     */
    RectangleDirective.prototype.rectangleDblclick;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.drag
     * @type {?}
     */
    RectangleDirective.prototype.rectangleDrag;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragend
     * @type {?}
     */
    RectangleDirective.prototype.rectangleDragend;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragstart
     * @type {?}
     */
    RectangleDirective.prototype.rectangleDragstart;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousedown
     * @type {?}
     */
    RectangleDirective.prototype.rectangleMousedown;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousemove
     * @type {?}
     */
    RectangleDirective.prototype.rectangleMousemove;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseout
     * @type {?}
     */
    RectangleDirective.prototype.rectangleMouseout;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseover
     * @type {?}
     */
    RectangleDirective.prototype.rectangleMouseover;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseup
     * @type {?}
     */
    RectangleDirective.prototype.rectangleMouseup;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.rightclick
     * @type {?}
     */
    RectangleDirective.prototype.rectangleRightclick;
    /**
     * The underlying google.maps.Rectangle object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle
     * @type {?}
     */
    RectangleDirective.prototype.restangle;
    /**
     * @type {?}
     * @private
     */
    RectangleDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    RectangleDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    RectangleDirective.prototype._eventService;
    /**
     * @type {?}
     * @private
     */
    RectangleDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/traffic-layer/traffic-layer.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Traffic Layer via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/map#TrafficLayer
 */
class TrafficLayerDirective {
    /**
     * @param {?} _mapService
     * @param {?} _ngZone
     */
    constructor(_mapService, _ngZone) {
        this._mapService = _mapService;
        this._ngZone = _ngZone;
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        changes.autoRefresh
            && !changes.autoRefresh.isFirstChange()
            && this.trafficLayer.setOptions(this._combineOptions());
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.trafficLayer && this.trafficLayer.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this._ngZone.runOutsideAngular((/**
         * @return {?}
         */
        () => {
            this.trafficLayer = new google.maps.TrafficLayer(this._combineOptions());
        }));
        this._assertInitialized();
        this.trafficLayer.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _combineOptions() {
        return { autoRefresh: this.autoRefresh };
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.trafficLayer) {
            throw Error('Cannot interact with a Google Map Traffic Layer before it has been initialized. ' +
                'Please wait for the Traffic Layer to load before trying to interact with it.');
        }
    }
}
TrafficLayerDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmTrafficLayer]' },] }
];
/** @nocollapse */
TrafficLayerDirective.ctorParameters = () => [
    { type: MapService },
    { type: NgZone }
];
TrafficLayerDirective.propDecorators = {
    autoRefresh: [{ type: Input }]
};
if (false) {
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/map#TrafficLayerOptions.autoRefresh
     * @type {?}
     */
    TrafficLayerDirective.prototype.autoRefresh;
    /**
     * The underlying google.maps.TrafficLayer object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#TrafficLayer
     * @type {?}
     */
    TrafficLayerDirective.prototype.trafficLayer;
    /**
     * @type {?}
     * @private
     */
    TrafficLayerDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    TrafficLayerDirective.prototype._mapService;
    /**
     * @type {?}
     * @private
     */
    TrafficLayerDirective.prototype._ngZone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/transit-layer/transit-layer.directive.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Angular directive that renders a Google Maps Traffic Layer via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/map#TransitLayer
 */
class TransitLayerDirective {
    /**
     * @param {?} _mapService
     */
    constructor(_mapService) {
        this._mapService = _mapService;
        this._destroy$ = new Subject();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this._mapService.load$
            .pipe(filter(Boolean), takeUntil(this._destroy$))
            .subscribe((/**
         * @return {?}
         */
        () => {
            this._onInit();
        }));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this._destroy$.next();
        this._destroy$.complete();
        this.transitLayer && this.transitLayer.setMap(null);
    }
    /**
     * @private
     * @return {?}
     */
    _onInit() {
        this.transitLayer = new google.maps.TransitLayer();
        this._assertInitialized();
        this.transitLayer.setMap(this._mapService.getMap());
    }
    /**
     * @private
     * @return {?}
     */
    _assertInitialized() {
        if (!this._mapService.getMap()) {
            throw Error('Cannot access Google Map information before the API has been initialized. ' +
                'Please wait for the API to load before trying to interact with it.');
        }
        if (!this.transitLayer) {
            throw Error('Cannot interact with a Google Map Traffic Layer before it has been initialized. ' +
                'Please wait for the Traffic Layer to load before trying to interact with it.');
        }
    }
}
TransitLayerDirective.decorators = [
    { type: Directive, args: [{ selector: '[dgmTransitLayer]' },] }
];
/** @nocollapse */
TransitLayerDirective.ctorParameters = () => [
    { type: MapService }
];
if (false) {
    /**
     * The underlying google.maps.TransitLayer object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#TransitLayer
     * @type {?}
     */
    TransitLayerDirective.prototype.transitLayer;
    /**
     * @type {?}
     * @private
     */
    TransitLayerDirective.prototype._destroy$;
    /**
     * @type {?}
     * @private
     */
    TransitLayerDirective.prototype._mapService;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/directives/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/script-protocol.enums.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const ScriptProtocol = {
    HTTP: 0,
    HTTPS: 1,
    AUTO: 2,
};
ScriptProtocol[ScriptProtocol.HTTP] = 'HTTP';
ScriptProtocol[ScriptProtocol.HTTPS] = 'HTTPS';
ScriptProtocol[ScriptProtocol.AUTO] = 'AUTO';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/enums/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/interfaces/api-loader-config.interface.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IAPILoaderConfig() { }
if (false) {
    /**
     * The Google Maps API Key.
     * See https://developers.google.com/maps/documentation/javascript/get-api-key
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.apiKey;
    /**
     * The Google Maps client ID.
     * See https://developers.google.com/maps/documentation/javascript/get-api-key
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.clientId;
    /**
     * The Google Maps channel name.
     * See https://developers.google.com/maps/premium/previous-licenses/clientside/quota
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.channel;
    /**
     * The Google maps API version.
     * See https://developers.google.com/maps/documentation/javascript/versions
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.apiVersion;
    /**
     * Host and Path used for the `<script>` tag
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.hostAndPath;
    /**
     * Protocol used for the `<script>` tag
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.protocol;
    /**
     * The google maps libraries.
     * See https://developers.google.com/maps/documentation/javascript/libraries
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.libraries;
    /**
     * The default bias for the map behavior is US.
     * If you wish to alter your application to serve different map tiles or bias the
     * application, you can overwrite the default behavior (US) by defining a `region`.
     * See https://developers.google.com/maps/documentation/javascript/basics#Region
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.region;
    /**
     * The Google Maps API uses the browser's preferred language when displaying
     * textual information. If you wish to overwrite this behavior and force the API
     * to use a given language, you can use this setting.
     * See https://developers.google.com/maps/documentation/javascript/basics#Language
     * @type {?|undefined}
     */
    IAPILoaderConfig.prototype.language;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/interfaces/google-event.target.interface.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function IMapGoogleEventTarget() { }
if (false) {
    /**
     * @param {?} name
     * @param {?} callback
     * @return {?}
     */
    IMapGoogleEventTarget.prototype.addListener = function (name, callback) { };
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/interfaces/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/api-config.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class APIConfig {
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/api-loader.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LazyMapsAPILoader extends MapsAPILoader {
    /**
     * @param {?} _config
     * @param {?} _windowRef
     * @param {?} _documentRef
     * @param {?} _localeId
     */
    constructor(_config, _windowRef, _documentRef, _localeId) {
        super();
        this._config = _config;
        this._windowRef = _windowRef;
        this._documentRef = _documentRef;
        this._localeId = _localeId;
    }
    /**
     * @return {?}
     */
    load() {
        /** @type {?} */
        const window = (/** @type {?} */ ((/** @type {?} */ (this._windowRef.getNativeWindow()))));
        if (window.google && window.google.maps) {
            this._scriptLoading$ = new ReplaySubject(1);
            this._scriptLoading$.next();
            this._scriptLoading$.complete();
            return this._scriptLoading$;
        }
        if (this._scriptLoading$) {
            return this._scriptLoading$;
        }
        /** @type {?} */
        const script = this._createElementScript();
        /** @type {?} */
        const callbackName = 'Create';
        script.src = this._getMapsScriptSrc(callbackName);
        this._scriptLoading$ = new ReplaySubject(1);
        this._windowRef.getNativeWindow()[callbackName] = (/**
         * @return {?}
         */
        () => {
            this._scriptLoading$.next();
            this._scriptLoading$.complete();
        });
        script.onerror = (/**
         * @param {?} error
         * @return {?}
         */
        (error) => { this._scriptLoading$.error(error); });
        this._documentRef.getNativeDocument().head.appendChild(script);
        return this._scriptLoading$;
    }
    /**
     * @private
     * @return {?}
     */
    _createElementScript() {
        /** @type {?} */
        const script = this._documentRef.getNativeDocument().createElement('script');
        script.type = 'text/javascript';
        script.async = true;
        script.defer = true;
        return script;
    }
    /**
     * @private
     * @param {?} callbackName
     * @return {?}
     */
    _getMapsScriptSrc(callbackName) {
        return this._getScriptSrc(this._getScriptUrl(), this._getQueryParams(callbackName));
    }
    /**
     * @private
     * @param {?} hostAndPath
     * @param {?} queryParams
     * @return {?}
     */
    _getScriptSrc(hostAndPath, queryParams) {
        /** @type {?} */
        const protocolType = (/** @type {?} */ (((this._config && this._config.protocol) || ScriptProtocol.HTTPS)));
        /** @type {?} */
        const protocol = this._getProtocol(protocolType);
        /** @type {?} */
        const params = this._getParams(queryParams);
        return `${protocol}//${hostAndPath}?${params}`;
    }
    /**
     * @private
     * @param {?} protocolType
     * @return {?}
     */
    _getProtocol(protocolType) {
        switch (protocolType) {
            case ScriptProtocol.AUTO:
                return '';
            case ScriptProtocol.HTTP:
                return 'http:';
            case ScriptProtocol.HTTPS:
                return 'https:';
        }
    }
    /**
     * @private
     * @param {?} queryParams
     * @return {?}
     */
    _getParams(queryParams) {
        return Object.keys(queryParams)
            .filter((/**
         * @param {?} k
         * @return {?}
         */
        (k) => queryParams[k] != null))
            .filter((/**
         * @param {?} k
         * @return {?}
         */
        (k) => {
            return !Array.isArray(queryParams[k]) ||
                (Array.isArray(queryParams[k]) && queryParams[k].length > 0);
        }))
            .map((/**
         * @param {?} k
         * @return {?}
         */
        (k) => {
            /** @type {?} */
            const i = queryParams[k];
            return Array.isArray(i) ? { key: k, value: i.join(',') }
                : { key: k, value: queryParams[k] };
        }))
            .map((/**
         * @param {?} entry
         * @return {?}
         */
        (entry) => `${entry.key}=${entry.value}`))
            .join('&');
    }
    /**
     * @private
     * @return {?}
     */
    _getScriptUrl() {
        return this._config.hostAndPath
            || 'maps.googleapis.com/maps/api/js';
    }
    /**
     * @private
     * @param {?} callbackName
     * @return {?}
     */
    _getQueryParams(callbackName) {
        return {
            version: this._config.apiVersion || 'quarterly',
            callback: callbackName,
            key: this._config.apiKey,
            client: this._config.clientId,
            channel: this._config.channel,
            libraries: this._config.libraries,
            region: this._config.region,
            language: this._config.language || (this._localeId !== 'en-US' ? this._localeId : null),
        };
    }
}
LazyMapsAPILoader.decorators = [
    { type: Injectable }
];
/** @nocollapse */
LazyMapsAPILoader.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [API_CONFIG,] }] },
    { type: WindowRef },
    { type: DocumentRef },
    { type: String, decorators: [{ type: Inject, args: [LOCALE_ID,] }] }
];
if (false) {
    /**
     * @type {?}
     * @private
     */
    LazyMapsAPILoader.prototype._scriptLoading$;
    /**
     * @type {?}
     * @private
     */
    LazyMapsAPILoader.prototype._config;
    /**
     * @type {?}
     * @private
     */
    LazyMapsAPILoader.prototype._windowRef;
    /**
     * @type {?}
     * @private
     */
    LazyMapsAPILoader.prototype._documentRef;
    /**
     * @type {?}
     * @private
     */
    LazyMapsAPILoader.prototype._localeId;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/maps.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @return {?}
 */
function mapsComponents() {
    return [
        BicyclingLayerDirective,
        CircleDirective,
        FitBoundsDirective,
        GroundOverlayDirective,
        KmlLayerDirective,
        MarkerDirective,
        MapComponent,
        PolygonDirective,
        PolylineDirective,
        RectangleDirective,
        TrafficLayerDirective,
        TransitLayerDirective,
    ];
}
class DgmMapsModule {
    /**
     * @param {?=} APILoaderConfig
     * @return {?}
     */
    static forRoot(APILoaderConfig) {
        return {
            ngModule: DgmMapsModule,
            providers: [
                ...BROWSER_PROVIDERS, { provide: MapsAPILoader, useClass: LazyMapsAPILoader },
                { provide: API_CONFIG, useValue: APILoaderConfig },
            ],
        };
    }
}
DgmMapsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ], declarations: mapsComponents(), exports: mapsComponents(),
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/services/index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: dxgm-maps.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { APIConfig, API_CONFIG, BROWSER_PROVIDERS, BicyclingLayerDirective, CircleDirective, DgmMapsModule, DocumentRef, EventService, FitBoundsAccessor, FitBoundsDirective, FitBoundsService, GroundOverlayDirective, KmlLayerDirective, LazyMapsAPILoader, MapComponent, MapService, MapsAPILoader, MarkerDirective, PROVIDERS, PolygonDirective, PolylineDirective, RectangleDirective, ScriptProtocol, TrafficLayerDirective, TransitLayerDirective, WindowRef, mapsComponents, BicyclingLayerDirective as ɵa, MapService as ɵb, MapsAPILoader as ɵc, CircleDirective as ɵd, EventService as ɵe, FitBoundsDirective as ɵf, FitBoundsAccessor as ɵg, FitBoundsService as ɵh, GroundOverlayDirective as ɵi, KmlLayerDirective as ɵj, MarkerDirective as ɵk, MapComponent as ɵl, PROVIDERS as ɵm, PolygonDirective as ɵn, PolylineDirective as ɵo, RectangleDirective as ɵp, TrafficLayerDirective as ɵq, TransitLayerDirective as ɵr, BROWSER_PROVIDERS as ɵs, WindowRef as ɵt, DocumentRef as ɵu, LazyMapsAPILoader as ɵv, API_CONFIG as ɵw };
//# sourceMappingURL=dxgm-maps.js.map
