/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Circle via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle
 */
export declare class CircleDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.center
     */
    center: google.maps.LatLngLiteral | google.maps.LatLng;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.draggable
     */
    draggable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.editable
     */
    editable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.radius
     */
    radius: number;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions
     */
    options: google.maps.CircleOptions;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#CircleOptions.visible
     */
    visible: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.center_changed
     */
    centerChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.click
     */
    circleClick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dblclick
     */
    circleDblclick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.drag
     */
    circleDrag: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragend
     */
    circleDragend: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.dragstart
     */
    circleDragstart: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousedown
     */
    circleMousedown: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mousemove
     */
    circleMousemove: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseout
     */
    circleMouseout: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseover
     */
    circleMouseover: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.mouseup
     */
    circleMouseup: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.radius_changed
     */
    radiusChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle.rightclick
     */
    circleRightclick: Observable<google.maps.MapMouseEvent>;
    /**
     * The underlying google.maps.Circle object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Circle
     */
    circle?: google.maps.Circle;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
