/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Ground Overlay via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
 */
export declare class GroundOverlayDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private readonly _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     */
    bounds: google.maps.LatLngBounds | google.maps.LatLngBoundsLiteral;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     */
    url: string;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlayOptions.clickable
     */
    clickable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlayOptions.opacity
     */
    opacity: number;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay.click
     */
    groundOverlayClick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay
     * #GroundOverlay.dblclick
     */
    groundOverlayDblclick: Observable<google.maps.MapMouseEvent>;
    /**
     * The underlying google.maps.GroundOverlay object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/image-overlay#GroundOverlay
     */
    groundOverlay?: google.maps.GroundOverlay;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _urlChanges;
    private _assertInitialized;
}
