/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Kml Layer via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer
 */
export declare class KmlLayerDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayerOptions
     */
    options: google.maps.KmlLayerOptions;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayerOptions.url
     */
    url: string;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml
     * #KmlLayer.defaultviewport_changed
     */
    defaultviewportChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer.status_changed
     */
    statusChanged: Observable<void>;
    /**
     * The underlying google.maps.KmlLayer object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/kml#KmlLayer
     */
    kmlLayer?: google.maps.KmlLayer;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
