/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Marker via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/map#Marker
 */
export declare class MarkerDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.clickable
     */
    clickable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.draggable
     */
    draggable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.label
     */
    label: string | google.maps.MarkerLabel;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.position
     */
    position: google.maps.LatLngLiteral | google.maps.LatLng;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions
     */
    options: google.maps.MarkerOptions;
    /**
     * See developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.title
     */
    title: string;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#MarkerOptions.visible
     */
    visible: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dblclick
     */
    markerDblclick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.drag
     */
    markerDrag: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragend
     */
    markerDragend: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.draggable_changed
     */
    draggableChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.dragstart
     */
    markerDragstart: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.flat_changed
     */
    flatChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.icon_changed
     */
    iconChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mousedown
     */
    markerMousedown: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseout
     */
    markerMouseout: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseover
     */
    markerMouseover: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.mouseup
     */
    markerMouseup: Observable<google.maps.MapMouseEvent>;
    /**
     * See developers.google.com/maps/documentation/javascript/reference/marker#Marker.position_changed
     */
    positionChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.rightclick
     */
    markerRightclick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.shape_changed
     */
    shapeChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.title_changed
     */
    titleChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.visible_changed
     */
    visibleChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/marker#Marker.zindex_changed
     */
    zindexChanged: Observable<void>;
    /**
     * The underlying google.maps.Marker object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/map#Marker
     */
    marker?: google.maps.Marker;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
