/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Polygon via the Google Maps JavaScript API.
 *
 * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon
 */
export declare class PolygonDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.draggable
     */
    draggable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.editable
     */
    editable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions
     */
    options: google.maps.PolygonOptions;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.paths
     */
    paths: google.maps.MVCArray<google.maps.MVCArray<google.maps.LatLng>> | google.maps.MVCArray<google.maps.LatLng> | google.maps.LatLng[] | google.maps.LatLngLiteral[];
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolygonOptions.visible
     */
    visible: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.click
     */
    polygonClick: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dblclick
     */
    polygonDblclick: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.drag
     */
    polygonDrag: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragend
     */
    polygonDragend: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.dragstart
     */
    polygonDragstart: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousedown
     */
    polygonMousedown: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mousemove
     */
    polygonMousemove: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseout
     */
    polygonMouseout: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseover
     */
    polygonMouseover: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.mouseup
     */
    polygonMouseup: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon.rightclick
     */
    polygonRightclick: Observable<google.maps.PolyMouseEvent>;
    /**
     * The underlying google.maps.Polygon object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polygon
     */
    polygon?: google.maps.Polygon;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
