/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Polyline via the Google Maps JavaScript API.
 *
 * See developers.google.com/maps/documentation/javascript/reference/polygon#Polyline
 */
export declare class PolylineDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.draggable
     */
    draggable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.editable
     */
    editable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions
     */
    options: google.maps.PolylineOptions;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.path
     */
    path: google.maps.MVCArray<google.maps.LatLng> | google.maps.LatLng[] | google.maps.LatLngLiteral[];
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#PolylineOptions.visible
     */
    visible: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.click
     */
    polylineClick: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dblclick
     */
    polylineDblclick: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.drag
     */
    polylineDrag: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragend
     */
    polylineDragend: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.dragstart
     */
    polylineDragstart: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousedown
     */
    polylineMousedown: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mousemove
     */
    polylineMousemove: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseout
     */
    polylineMouseout: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseover
     */
    polylineMouseover: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.mouseup
     */
    polylineMouseup: Observable<google.maps.PolyMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline.rightclick
     */
    polylineRightclick: Observable<google.maps.PolyMouseEvent>;
    /**
     * The underlying google.maps.Polyline object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Polyline
     */
    polyline?: google.maps.Polyline;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
