/// <reference types="googlemaps" />
import { NgZone, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Observable } from 'rxjs';
import { MapService } from '../../services/map.service';
import { EventService } from '../../services/event.service';
/**
 * Angular directive that renders a Google Maps Rectangle via the Google Maps JavaScript API.
 *
 * See developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle
 */
export declare class RectangleDirective implements OnInit, OnChanges, OnDestroy {
    private readonly _mapService;
    private _eventService;
    private readonly _ngZone;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.bounds
     */
    bounds: google.maps.LatLngBounds | google.maps.LatLngBoundsLiteral;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.draggable
     */
    draggable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.editable
     */
    editable: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions
     */
    options: google.maps.RectangleOptions;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#RectangleOptions.visible
     */
    visible: boolean;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.boundsChanged
     */
    boundsChanged: Observable<void>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.click
     */
    rectangleClick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dblclick
     */
    rectangleDblclick: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.drag
     */
    rectangleDrag: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragend
     */
    rectangleDragend: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.dragstart
     */
    rectangleDragstart: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousedown
     */
    rectangleMousedown: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mousemove
     */
    rectangleMousemove: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseout
     */
    rectangleMouseout: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseover
     */
    rectangleMouseover: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.mouseup
     */
    rectangleMouseup: Observable<google.maps.MapMouseEvent>;
    /**
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle.rightclick
     */
    rectangleRightclick: Observable<google.maps.MapMouseEvent>;
    /**
     * The underlying google.maps.Rectangle object
     *
     * See https://developers.google.com/maps/documentation/javascript/reference/polygon#Rectangle
     */
    restangle?: google.maps.Rectangle;
    private readonly _destroy$;
    constructor(_mapService: MapService, _eventService: EventService, _ngZone: NgZone);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    private _onInit;
    private _combineOptions;
    private _assertInitialized;
}
